@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import manimlib.config
+import manimlib.logger
 import manimlib.extract_scene
 import manimlib.utils.init_config
 from manimlib import __version__
@@ -9,8 +10,10 @@ def main():
     print(f"ManimGL \033[32mv{__version__}\033[0m")
 
     args = manimlib.config.parse_cli()
-    if args.version and args.file == None:
+    if args.version and args.file is None:
         return
+    if args.log_level:
+        manimlib.logger.log.setLevel(args.log_level)
 
     if args.config:
         manimlib.utils.init_config.init_customization()
@@ -21,5 +24,6 @@ def main():
         for scene in scenes:
             scene.run()
 
+
 if __name__ == "__main__":
     main()
