@@ -305,6 +305,9 @@ class Circle(Arc):
             (angle - start_angle) / TAU
         )
 
+    def get_radius(self):
+        return get_norm(self.get_start() - self.get_center())
+
 
 class Dot(Circle):
     CONFIG = {
@@ -507,6 +510,7 @@ class Line(TipableVMobject):
 
     def set_length(self, length, **kwargs):
         self.scale(length / self.get_length(), **kwargs)
+        return self
 
 
 class DashedLine(Line):
